@@ -12,7 +12,7 @@ import (
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoitest"
 )
 
-func TestGuessDotfilesRepoURL(t *testing.T) {
+func TestGuessRepoURL(t *testing.T) {
 	for _, tc := range []struct {
 		arg                  string
 		expectedHTTPRepoURL  string
@@ -26,85 +26,85 @@ func TestGuessDotfilesRepoURL(t *testing.T) {
 		},
 		{
 			arg:                  "codeberg.org/user",
-			expectedHTTPRepoURL:  "https://user@codeberg.org/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://codeberg.org/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@codeberg.org:user/dotfiles.git",
 		},
 		{
 			arg:                  "codeberg.org/user/dots",
-			expectedHTTPRepoURL:  "https://user@codeberg.org/user/dots.git",
+			expectedHTTPRepoURL:  "https://codeberg.org/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@codeberg.org:user/dots.git",
 		},
 		{
 			arg:                  "gitlab.com/user",
-			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://gitlab.com/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dotfiles.git",
 		},
 		{
 			arg:                  "gitlab.com/user/dots",
-			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "http://gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "http://user@gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "http://gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "https://gitlab.com/user/dots.git",
-			expectedHTTPRepoURL:  "https://user@gitlab.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://gitlab.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@gitlab.com:user/dots.git",
 		},
 		{
 			arg:                  "sr.ht/~user_name",
-			expectedHTTPRepoURL:  "https://user_name@git.sr.ht/~user_name/dotfiles",
+			expectedHTTPRepoURL:  "https://git.sr.ht/~user_name/dotfiles",
 			expectedHTTPUsername: "user_name",
 			expectedSSHRepoURL:   "git@git.sr.ht:~user_name/dotfiles",
 		},
 		{
 			arg:                  "sr.ht/~user_name/dots",
-			expectedHTTPRepoURL:  "https://user_name@git.sr.ht/~user_name/dots",
+			expectedHTTPRepoURL:  "https://git.sr.ht/~user_name/dots",
 			expectedHTTPUsername: "user_name",
 			expectedSSHRepoURL:   "git@git.sr.ht:~user_name/dots",
 		},
 		{
 			arg:                  "user",
-			expectedHTTPRepoURL:  "https://user@github.com/user/dotfiles.git",
+			expectedHTTPRepoURL:  "https://github.com/user/dotfiles.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dotfiles.git",
 		},
 		{
 			arg:                  "user/dots",
-			expectedHTTPRepoURL:  "https://user@github.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://github.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dots.git",
 		},
 		{
 			arg:                  "user/dots.git",
-			expectedHTTPRepoURL:  "https://user@github.com/user/dots.git",
+			expectedHTTPRepoURL:  "https://github.com/user/dots.git",
 			expectedHTTPUsername: "user",
 			expectedSSHRepoURL:   "git@github.com:user/dots.git",
 		},
 	} {
 		t.Run(tc.arg, func(t *testing.T) {
 			ssh := false
-			actualHTTPUsername, actualHTTPRepoURL := guessDotfilesRepoURL(tc.arg, ssh)
+			actualHTTPUsername, actualHTTPRepoURL := guessRepoURL(tc.arg, ssh)
 			assert.Equal(t, tc.expectedHTTPUsername, actualHTTPUsername, "HTTPUsername")
 			assert.Equal(t, tc.expectedHTTPRepoURL, actualHTTPRepoURL, "HTTPRepoURL")
 
 			ssh = true
-			actualSSHUsername, actualSSHRepoURL := guessDotfilesRepoURL(tc.arg, ssh)
+			actualSSHUsername, actualSSHRepoURL := guessRepoURL(tc.arg, ssh)
 			assert.Equal(t, "", actualSSHUsername, "SSHUsername")
 			assert.Equal(t, tc.expectedSSHRepoURL, actualSSHRepoURL, "SSHRepoURL")
 		})
